## v0.4.0 (2025-06-17)

### Feat

- rename files with and without time labels

## v0.3.0 (2025-06-17)

### Feat

- **restore**: change ownership of restored files

## v0.2.1 (2025-06-16)

### Fix

- accept strings or Path for logfile location

## v0.2.0 (2025-06-16)

### Feat

- initial commit
